@@ -1,7 +1,7 @@
-package MooseX::Getopt; # git description: v0.65-1-g4973fbb
+package MooseX::Getopt; # git description: v0.66-14-g157612e
 # ABSTRACT: A Moose role for processing command line options
 # KEYWORDS: moose extension command line options attributes executable flags switches arguments
-$MooseX::Getopt::VERSION = '0.66';
+our $VERSION = '0.67';
 use Moose::Role 0.56;
 use namespace::autoclean;
 
@@ -21,7 +21,7 @@ MooseX::Getopt - A Moose role for processing command line options
 
 =head1 VERSION
 
-version 0.66
+version 0.67
 
 =head1 SYNOPSIS
 
@@ -305,7 +305,7 @@ the same terms as the Perl 5 programming language system itself.
 
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Tomas Doran Stevan Little Yuval Kogman Florian Ragwitz Brandon L Black Shlomi Fish Hans Dieter Pearcey Ryan D Johnson Nelo Onyiah Ricardo SIGNES Ævar Arnfjörð Bjarmason Damien Krotkine Hinrik Örn Sigurðsson Devin Austin Todd Hepler Chris Prather John Goulah Jesse Luehrs Justin Hunter Drew Taylor Dagfinn Ilmari Mannsåker Gordon Irving Jonathan Swartz Olaf Alders
+=for stopwords Karen Etheridge Tomas Doran Stevan Little Yuval Kogman Florian Ragwitz Brandon L Black Shlomi Fish Hans Dieter Pearcey Ryan D Johnson Nelo Onyiah Ricardo SIGNES Ævar Arnfjörð Bjarmason Damien Krotkine Hinrik Örn Sigurðsson Todd Hepler Devin Austin Jose Luis Martinez Chris Prather Justin Hunter Gordon Irving Dagfinn Ilmari Mannsåker Jesse Luehrs Olaf Alders Jonathan Swartz John Goulah
 
 =over 4
 
@@ -367,11 +367,15 @@ Hinrik Örn Sigurðsson <hinrik.sig@gmail.com>
 
 =item *
 
+Todd Hepler <thepler@employees.org>
+
+=item *
+
 Devin Austin <devin@devin-laptop.(none)>
 
 =item *
 
-Todd Hepler <thepler@employees.org>
+Jose Luis Martinez <jlmartinez@capside.com>
 
 =item *
 
@@ -379,36 +383,32 @@ Chris Prather <chris@prather.org>
 
 =item *
 
-John Goulah <jgoulah@cpan.org>
-
-=item *
-
-Jesse Luehrs <doy@tozt.net>
-
-=item *
-
 Justin Hunter <justin.d.hunter@gmail.com>
 
 =item *
 
-Drew Taylor <drew@drewtaylor.com>
-
-=item *
-
-Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
-
-=item *
-
 Gordon Irving <goraxe@goraxe.me.uk>
 
 =item *
 
-Jonathan Swartz <swartz@pobox.com>
+Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
 
 =item *
 
 Olaf Alders <olaf@wundersolutions.com>
 
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+John Goulah <jgoulah@cpan.org>
+
 =back
 
 =cut
